# List of IDEAs for the raman fitting code
```py
# IDEA change version definition

# IDEA list:
# added setup.cfg
# added unittests
# added README.md
# add project.toml only for
# improved logger, each module needs a getlogger(name)
# IDEA future daemonize the fitting process for using the package and dropping files in the datafiles folder
# IDEA add docs with Sphinx, readthedocs
# IDEA improve AsyncIO into main delegator processes
# IDEA fix plotting because of DeprecationWarning in savefig
# IDEA add database for spectrum data storage
# IDEA future GUI webinterface

# IDEA improve fitting loop so that starting parameters from modelX and modelX+Si are shared, faster...
```